timesignaturetools.is_time_signature_with_equivalent_binary_representation
==========================================================================

.. autofunction:: abjad.tools.timesignaturetools.is_time_signature_with_equivalent_binary_representation.is_time_signature_with_equivalent_binary_representation
